/* Package name (qvwm) */
#undef PACKAGE
/* Package version */
#undef VERSION

/* Define if you want a debug version of qvwm */
#undef DEBUG

/* Define if you allow sending commands to qvwm */
#undef ALLOW_RMTCMD

/* Define if you want to use Imlib */
#undef USE_IMLIB

/* Define if the X shape extension is available */
#undef USE_SHAPE

/* Define if the X Session Management Protocol is available */
#undef USE_XSMP

/* Define if you want to use ALSA for sound effects (Linux only) */
#undef USE_ALSA

/* Define if you want to use esd (EsounD) for sound effects */
#undef USE_ESD

/* Define if you want to use screen saver functions */
#undef USE_SS

/* Define if the X screen saver extension is available */
#undef USE_SSEXT

/* Define if the X server supports locale functions */
#undef X_LOCALE
